@@ -372,7 +372,7 @@ int IsAlpha(unsigned int c)
 {//========================
 // Replacement for iswalph() which also checks for some in-word symbols
 
-	const unsigned short extra_indic_alphas[] = {
+	static const unsigned short extra_indic_alphas[] = {
 	0xa70,0xa71,	// Gurmukhi: tippi, addak
 	0 };
 
@@ -1013,7 +1013,7 @@ if((wmark > 0) && (wmark < 8))
 			found = TranslateNumber(tr, word1, phonemes, dictionary_flags, wtab, 0);
 		}
 
-		if(!found & ((wflags & FLAG_UPPERS) != FLAG_FIRST_UPPER))
+		if(!found && ((wflags & FLAG_UPPERS) != FLAG_FIRST_UPPER))
 		{
 			// either all upper or all lower case
 
@@ -2797,6 +2797,20 @@ if((c == '/') && (tr->langopts.testing & 2) && IsDigit09(next_in) && IsAlpha(pre
 
 				letter_count++;
 
+				if(tr->letter_bits_offset > 0)
+				{
+					if(((c < 0x250) && (prev_out >= tr->letter_bits_offset)) ||
+						((c >= tr->letter_bits_offset) && (letter_count > 1) && (prev_out < 0x250)))
+					{
+						// Don't mix native and Latin characters in the same word
+						// Break into separate words
+						c = ' ';
+						space_inserted = 1;
+						word_flags |= FLAG_HYPHEN_AFTER;
+						next_word_flags |= FLAG_HYPHEN;
+					}
+				}
+
 				if(iswupper(c))
 				{
 					c = towlower2(c);
